<?php

namespace B2buy\MasterSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use B2buy\MasterSetting\Http\Requests\MasterSettingsRequest;
use B2buy\MasterSetting\Interfaces\MasterSettingsRepositoryInterface;
use B2buy\MasterSetting\Models\MasterSettings;

/**
 * Resource controller class for master_settings.
 */
class MasterSettingsResourceController extends BaseController
{

    /**
     * Initialize master_settings resource controller.
     *
     * @param type MasterSettingsRepositoryInterface $master_settings
     *
     * @return null
     */
    public function __construct(MasterSettingsRepositoryInterface $master_settings)
    {
        parent::__construct();
        $this->repository = $master_settings;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\MasterSetting\Repositories\Criteria\MasterSettingsResourceCriteria::class);
    }

    /**
     * Display a list of master_settings.
     *
     * @return Response
     */
    public function index(MasterSettingsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\B2buy\MasterSetting\Repositories\Presenter\MasterSettingsPresenter::class)
                ->$function();
        }

        $master_settings = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('master_setting::master_settings.names'))
            ->view('master_setting::master_settings.index', true)
            ->data(compact('master_settings', 'view'))
            ->output();
    }

    /**
     * Display master_settings.
     *
     * @param Request $request
     * @param Model   $master_settings
     *
     * @return Response
     */
    public function show(MasterSettingsRequest $request, MasterSettings $master_settings)
    {

        if ($master_settings->exists) {
            $view = 'master_setting::master_settings.show';
        } else {
            $view = 'master_setting::master_settings.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('master_setting::master_settings.name'))
            ->data(compact('master_settings'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new master_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(MasterSettingsRequest $request)
    {

        $master_settings = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('master_setting::master_settings.name')) 
            ->view('master_setting::master_settings.create', true) 
            ->data(compact('master_settings'))
            ->output();
    }

    /**
     * Create new master_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MasterSettingsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $master_settings                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('master_setting::master_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('master_setting/master_settings/' . $master_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/master_setting/master_settings'))
                ->redirect();
        }

    }

    /**
     * Show master_settings for editing.
     *
     * @param Request $request
     * @param Model   $master_settings
     *
     * @return Response
     */
    public function edit(MasterSettingsRequest $request, MasterSettings $master_settings)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('master_setting::master_settings.name'))
            ->view('master_setting::master_settings.edit', true)
            ->data(compact('master_settings'))
            ->output();
    }

    /**
     * Update the master_settings.
     *
     * @param Request $request
     * @param Model   $master_settings
     *
     * @return Response
     */
    public function update(MasterSettingsRequest $request, MasterSettings $master_settings)
    {
        try {
            $attributes = $request->all();

            $master_settings->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('master_setting::master_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('master_setting/master_settings/' . $master_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master_setting/master_settings/' . $master_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the master_settings.
     *
     * @param Model   $master_settings
     *
     * @return Response
     */
    public function destroy(MasterSettingsRequest $request, MasterSettings $master_settings)
    {
        try {

            $master_settings->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('master_setting::master_settings.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('master_setting/master_settings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master_setting/master_settings/' . $master_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple master_settings.
     *
     * @param Model   $master_settings
     *
     * @return Response
     */
    public function delete(MasterSettingsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('master_setting::master_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('master_setting/master_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/master_setting/master_settings'))
                ->redirect();
        }

    }

    /**
     * Restore deleted master_settings.
     *
     * @param Model   $master_settings
     *
     * @return Response
     */
    public function restore(MasterSettingsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('master_setting::master_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/master_setting/master_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/master_setting/master_settings/'))
                ->redirect();
        }

    }

}
